# 0.1.5
- Increase `MAX_EVENT_SIZE` to send via websocket

# 0.1.4
- Fix runner command

# 0.1.3
- Add `textual-tags` to filter based on test markers
- Add SearchModal to search for tests also add favourite function
and filtering for NodeTypes

# 0.1.X
- Initial test releases
